@@ -1,7 +1,7 @@
 package IPC::System::Options;
 
-our $DATE = '2015-07-03'; # DATE
-our $VERSION = '0.17'; # VERSION
+our $DATE = '2015-07-27'; # DATE
+our $VERSION = '0.18'; # VERSION
 
 use strict;
 use warnings;
@@ -20,7 +20,7 @@ sub import {
     while ($i < @_) {
         if ($_[$i] eq 'system' || $_[$i] eq 'backtick' || $_[$i] eq 'import') {
             no strict 'refs';
-            *{"$caller\::$_[$i]"} = \&{$_[$i]};
+            *{"$caller\::$_[$i]"} = \&{"$self\::" . $_[$i]};
         } elsif ($_[$i] =~ /\A-(.+)/) {
             croak "$_[$i] requires an argument" unless $i < @_-1;
             $Global_Opts{$1} = $_[$i+1];
@@ -209,7 +209,7 @@ IPC::System::Options - Perl's system() and backtick/qx replacement/wrapper, with
 
 =head1 VERSION
 
-This document describes version 0.17 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-07-03.
+This document describes version 0.18 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-07-27.
 
 =head1 SYNOPSIS
 
